%global _version        2020-12-R3

## {Local macros...
%global cfgdir          %_sysconfdir/%name
%global _rpmversion     %(echo %_version | tr - .)
## ...local macros}

%{!?apply:%global  apply(p:n:b:) %patch%%{-n:%%{-n*}} %%{-p:-p%%{-p*}} %%{-b:-b%%{-b*}} \
%nil}

Summary:        WLAN detector, sniffer and IDS
Name:           kismet
Version:        %_rpmversion
Release:        %mkrel 2
Group:          Networking/Other
License:        GPLv2+
URL:            http://www.kismetwireless.net/
Source0:        http://www.kismetwireless.net/code/%{name}-%_version.tar.xz
Source1:        README.urpmi

Patch0:         kismet-include.patch
Patch1:         kismet-install.patch

BuildRequires:  pkgconfig(ncurses)
BuildRequires:  libpcap-devel
BuildRequires:  libnl3-devel
BuildRequires:  pkgconfig(bluez)
BuildRequires:  pkgconfig(openssl)
BuildRequires:  diffutils
BuildRequires:  libmicrohttpd-devel
BuildRequires:  protobuf-devel
BuildRequires:  protobuf-c-devel
BuildRequires:  pkgconfig(libnm)
BuildRequires:  pkgconfig(sqlite3)
BuildRequires:  pkgconfig(libwebsockets)
BuildRequires:  pkgconfig(libcap)
BuildRequires:  lm_sensors-devel
BuildRequires:  pkgconfig(libusb-1.0)
BuildRequires:  python3-setuptools

# (doktor5000) required for the creation of the group to run suid capture helper
Requires(pre):    rpm-helper
Requires(post):   rpm-helper
Requires(preun):  rpm-helper
Requires(postun): rpm-helper

%description
Kismet is an 802.11 layer2 wireless network detector, sniffer, and
intrusion detection system. Kismet will work with any wireless card
which supports raw monitoring (rfmon) mode, and can sniff 802.11b,
802.11a, and 802.11g traffic.

Kismet identifies networks by passively collecting packets and detecting
standard named networks, detecting (and given time, decloaking) hidden
networks, and infering the presence of nonbeaconing networks via data
traffic.

%prep
%setup -qn %{name}-%{_version}

%patch0 -p0
%patch1 -p0

sed -i 's!\$(prefix)/lib/!%{_libdir}/!g' plugin-*/Makefile


# set our 'kismet' user, disable GPS and log into %%logdir by
# default
sed -i \
    -e '\!^ouifile=/etc/manuf!d' \
    -e '\!^ouifile=/usr/share/wireshark/wireshark/manuf!d' \
    conf/kismet.conf

%build

export ac_cv_lib_uClibcpp_main=no # we do not want to build against uClibc++, even when available
export LDFLAGS='-Wl,--as-needed'
%configure \
           --sysconfdir=%cfgdir \
           CXXFLAGS="$RPM_OPT_FLAGS -D__STDC_FORMAT_MACROS"

%make_build

sed -i s/2019-08-GIT/%{version}-%{release}%{?dist}/g packaging/kismet.pc

%install
BIN=$RPM_BUILD_ROOT/%{_bindir} ETC=$RPM_BUILD_ROOT/etc %make_install

# Currently broken (maybe due to python version)
rm -f %{buildroot}/%{_bindir}/kismet_cap_sdr_rtla*

%pre
# (doktor5000) add kismet group to run suid capture helper
%_pre_groupadd %{name}

%postun
%_postun_groupdel %{name}

%files
%doc CHANGELOG README* docs/
%dir %attr(0755,root,root) %cfgdir
%config(noreplace) %cfgdir/*
%{_bindir}/kismet
%attr(4750,root,%{name}) %{_bindir}/kismet_cap*
%{_bindir}/kismetdb*
%{_bindir}/kismet_discovery
%{_bindir}/kismet_server
%{_datadir}/kismet
%{_libdir}/pkgconfig/kismet.pc
%{python3_sitelib}/Kismet*



%changelog
* Fri Jan 15 2021 pterjan <pterjan> 2020.12.R3-2.mga8
+ Revision: 1671911
- Drop broken python capture tools
- Fix permissions to have capture helpers suid
- Update to 2020-12-R3

* Thu Feb 13 2020 umeabot <umeabot> 2016.07.R1-3.mga8
+ Revision: 1513744
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Sun Sep 23 2018 umeabot <umeabot> 2016.07.R1-2.mga7
+ Revision: 1298562
- Mageia 7 Mass Rebuild

* Fri Sep 15 2017 guillomovitch <guillomovitch> 2016.07.R1-1.mga7
+ Revision: 1154144
- new version 2016-07-R1
- enable btscan and spectools plugins
- don't mess with configuration file during post-installation

* Tue Feb 09 2016 umeabot <umeabot> 2013.03.R1b-5.mga6
+ Revision: 952578
- Mageia 6 Mass Rebuild

* Wed Mar 11 2015 doktor5000 <doktor5000> 2013.03.R1b-4.mga5
+ Revision: 818422
- bump release to be able to submit to core/release

* Tue Mar 10 2015 doktor5000 <doktor5000> 2013.03.R1b-3.mga5
+ Revision: 818312
+ rebuild (emptylog)

* Tue Mar 03 2015 doktor5000 <doktor5000> 2013.03.R1b-2.mga5
+ Revision: 817551
- fix permissions of SUID kismet_capture binary
- rephrased section and fixed typo in README.urpmi
- dropped Recommends on wireshark, flite and festival

* Mon Mar 02 2015 doktor5000 <doktor5000> 2013.03.R1b-1.mga5
+ Revision: 817363
- new version 2013-03-R1b
- added SUID kismet_capture binary to allow capturing as non-root user
  o added README.urpmi to document two ways of using kismet
  o add necessary kismet group via rpm-helper
  o use %%serverbuild macro to build kismet due to the SUID binary
- enabled new alertsyslog plugin
- reenabled AutoWEP plugin
- added Recommends on wireshark for IEEE OUI file for automatic NIC MAC lookup
- added Recommends on flite & festival to enable speech output on kismet server

* Wed Oct 15 2014 umeabot <umeabot> 2011.03.R2-7.mga5
+ Revision: 741240
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 2011.03.R2-6.mga5
+ Revision: 681095
- Mageia 5 Mass Rebuild

* Fri Oct 18 2013 umeabot <umeabot> 2011.03.R2-5.mga4
+ Revision: 506681
- Mageia 4 Mass Rebuild

* Sat Jan 12 2013 umeabot <umeabot> 2011.03.R2-4.mga3
+ Revision: 356249
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Tue Mar 20 2012 tmb <tmb> 2011.03.R2-3.mga3
+ Revision: 225013
- build against libnl3
+ doktor5000 <doktor5000>
- fix order of options in sed call in %%post

* Wed Aug 31 2011 doktor5000 <doktor5000> 2011.03.R2-1.mga2
+ Revision: 137314
- new version 2011-03-R2, switching to Newcore
- change versioning scheme to represent upstream versioning
- build additional plugins autowep and ptw, enabling aircrack integration
- remove unused BuildRequire glib-devel
- removed obsolete README.Mandriva
- fix license to GPLv2+
- drop obsolete fix.h header
- drop obsolete patches
- imported package kismet

